package com.zhentao.moment.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zhentao.moment.domain.UserMoments;
import com.zhentao.moment.dto.MonmentDto;
import com.zhentao.moment.enums.ContentTypeEnum;
import com.zhentao.moment.service.UserMomentsService;
import com.zhentao.moment.mapper.UserMomentsMapper;
import com.zhentao.tool.TokenUtils;
import com.zhentao.utils.SensitiveWordFilter;
import com.zhentao.utils.SnowflakeUtil;
import com.zhentao.vo.Result;
import io.jsonwebtoken.Claims;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
* @author 86159
* @description 针对表【user_moments(朋友圈动态表)】的数据库操作Service实现
* @createDate 2025-06-04 11:56:59
*/
@Service
public class UserMomentsServiceImpl extends ServiceImpl<UserMomentsMapper, UserMoments>
    implements UserMomentsService{
    @Autowired
    private UserMomentsMapper userMomentsMapper;
    @Override
    public Result sendMonment(String token,MonmentDto monmentDto) {
        if (monmentDto.getContent()==null){
            return Result.error(400,"请输入内容");
        }
        if (monmentDto.getContentType()==null){
            return Result.error(400,"内容类型不能为空");
        }
        try {
            UserMoments userMoments=new UserMoments();
            userMoments.setMomentId(SnowflakeUtil.nextId());
            String userId = TokenUtils.getUserIdFromToken(token);
            userMoments.setUserId(Long.valueOf(userId));
            Integer typeCode = monmentDto.getContentType();
            ContentTypeEnum type = ContentTypeEnum.getByCode(typeCode);
            switch (type){
                case TEXT:
                    String filter = SensitiveWordFilter.filter(monmentDto.getContent());
                    userMoments.setContent(filter);
                    break;
                case IMAGE:
                    validateImageContent(monmentDto.getContent());
//                    userMoments.setContentType(ContentTypeEnum.IMAGE.getCode());
                    break;
                case VIDEO:
                    validateVideoContent(monmentDto.getContent());
//                    userMoments.setContentType(ContentTypeEnum.VIDEO.getCode());
                    break;
                default:
                    return Result.error(400,"内容类型错误");
            }
////            userMoments.setContentType();
//            userMoments.setContent(monmentDto.getContent());
            userMomentsMapper.insert(userMoments);
        }catch (Exception e){
            e.printStackTrace();
        }
        return Result.OK(null,"发送成功");
    }

//    @Override
//    public Result deleteMonment(MonmentDto monmentDto) {
//
//
//    }

    // 图片内容校验
    private void validateImageContent(String content) {
        // content 存图片 URL 列表，用逗号分隔
        String[] imageUrls = content.split(",");
        for (String url : imageUrls) {
            if (!url.matches("^https?://.*\\.(png|jpg|jpeg)$")) {
                throw new IllegalArgumentException("图片 URL 格式错误: " + url);
            }
        }
    }

    // 视频内容校验
    private void validateVideoContent(String content) {
        //  content 存视频 URL
        if (!content.matches("^https?://.*\\.(mp4|avi)$")) {
            throw new IllegalArgumentException("视频 URL 格式错误: " + content);
        }
    }
}




